@@ -1,6 +1,7 @@
-"""A friendly Python Utilitary RPA."""
+"""Utilizario de funciones usadas en los procesos de robotizacion
+   con Python."""
 
-__version__ = "1.20"
+__version__ = "1.21"
 __author__ = "Jonathan Bolo"
 
 import os, re, shutil
@@ -31,7 +32,16 @@ import numpy as np
 log=logging.getLogger(__name__)
 log.addHandler(NullHandler())
 
-def xlsx_to_csv(filename,sheet,newfilename,separator):
+def xlsx_to_csv(filename="",sheet="",newfilename="",separator=""):
+    """Funcion que mediante openpyxnl convierne un xlsx a csv(usar Pandas).
+
+    Args:
+        filename (str, optional): Archivo a convertir. Defaults to "".
+        sheet (str, optional): Hoja a convertir del excel. Defaults to "".
+        newfilename (str, optional): Archivo csv destino. Defaults to "".
+        separator (str, optional): Separador a usar en el csv. Defaults to "".
+    """
+    
     import openpyxl
     import csv
     xlsx = openpyxl.load_workbook(filename)
@@ -60,12 +70,13 @@ def xlsx_to_csv(filename,sheet,newfilename,separator):
 
     return
 
-def upload_file_sftp(filename, destine_path, credentials):
-    """ Subir archivo(s) a SFTP
-    :param filename: Nombre de archivo(acepta comodines unix * ?) o lista de archivos.
-    :param destine_path: Ruta destino remoto
-    :param credentials: Credenciales de conexion al SFTP
-    :return: None
+def upload_file_sftp(filename, destine_path="", credentials={}):
+    """Funcion que sube archivos a un SFTP
+
+    Args:
+        filename (list, optional): Nombre de archivo(acepta comodines unix * ?) o lista de archivos. Defaults to [].
+        destine_path (str, optional): Ruta destino remoto. Defaults to {}.
+        recursive (bool, optional): Flag que permite crear directorios recursivamente. Defaults to False.
     """
     import paramiko
 
@@ -121,15 +132,16 @@ def upload_file_sftp(filename, destine_path, credentials):
                 
                 if not flag_exists:
                     raise Exception("No se encontró coincidencias para: " + filename)
-    
-    return
 
-def makedir_sftp(sftp_path, credentials, recursive = False):
-    """ Crea directorio SFTP
-    :param sftp_path: Directorio remoto a crear
-    :param credentials: Credenciales de conexion al SFTP
-    :return: None
+def makedir_sftp(sftp_path="", credentials={}, recursive = False):
+    """Funcion que crea directorios en un SFTP
+
+    Args:
+        sftp_path (str, optional): Ruta remoto a crear. Defaults to "".
+        credentials (dict, optional): Diccionario con credenciales. Defaults to {}.
+        recursive (bool, optional): Flag que permite crear directorios recursivamente. Defaults to False.
     """
+    
     import paramiko
 
     puerto = 22
@@ -189,13 +201,19 @@ def makedir_sftp(sftp_path, credentials, recursive = False):
                 else:
                     log.info("Directorio no recursivo ya existe:" + sftp_path)
 
-def list_sftp(sftp_path, credentials, attr=False):
-    """ Lista archivo(s) de un directorio SFTP
-    :param sftp_path: Directorio remoto a listar
-    :param credentials: Credenciales de conexion al SFTP
-    :param attr: Flag que activa el retorno de (list of SFTPAttributes) en vez de los clasicos (list of str)
-    :return: None
+def list_sftp(sftp_path="", credentials={}, attr=False):
+    """Funcion que lista archivos de un SFTP
+
+    Args:
+        sftp_path (str, optional): Ruta remoto a listar. Defaults to "".
+        credentials (dict, optional): Diccionario con credenciales. Defaults to {}.
+        attr (bool, optional): Flag que permite borrar el archivo origen. Defaults to False.
+
+    Returns:
+        list: Lista de archivos y directorios encontrado
     """
+    
+    
     import paramiko
 
     puerto = 22
@@ -221,12 +239,15 @@ def list_sftp(sftp_path, credentials, attr=False):
                 filelist = server.listdir()
             return filelist
 
-def remove_sftp(list_files_sftp, credentials, attr=False):
-    """ Borra archivo(s) del sftp
-    :param list_files_sftp: Lista de archivos a borrar
-    :param credentials: Credenciales de conexion al SFTP
-    :return: None
+def remove_sftp(list_files_sftp=[], credentials={}, attr=False):
+    """Funcion que borra archivos de un SFTP
+    
+    Args:
+        list_files_sftp (list, optional): Lista de archivos a borrar. Defaults to "".
+        credentials (dict, optional): Diccionario con credenciales. Defaults to {}.
+        attr (bool, optional): Flag que permite borrar el archivo origen. Defaults to False.
     """
+    
     import paramiko
 
     puerto = 22
@@ -253,13 +274,15 @@ def remove_sftp(list_files_sftp, credentials, attr=False):
                     log.info(str(e))
                     log.info("Ocurrio un error al borrar el archivo: " + file)
     
-def download_file_sftp(filename, destine_path, credentials, flag_remove = False):
-    """ Descargar archivo(s) SFTP
-    :param filename: Nombre de archivo(acepta comodines unix * ?) o lista de archivos.
-    :param destine_path: Ruta destino remoto
-    :param credentials: Credenciales de conexion al SFTP
-    :param flag_remove: Flag que determina borrar o no los archivos remotos una vez descargados
-    :return: None
+def download_file_sftp(filename="", destine_path="", credentials={}, flag_remove = False):
+    """Funcion que descargar archivos de un SFTP
+
+    Args:
+        filename (str, optional): Nombre de archivo(acepta comodines unix * ?) o lista de archivos. Defaults to "".
+        destine_path (str, optional): Prefijo de archivo a descargar. Defaults to "".
+        downloadPath (str, optional): Ruta destino remoto. Defaults to "".
+        credentials (dict, optional): Diccionario con credenciales. Defaults to {}.
+        flag_remove (bool, optional): Flag que permite borrar el archivo origen. Defaults to False.
     """
 
     import paramiko
@@ -329,7 +352,17 @@ def download_file_sftp(filename, destine_path, credentials, flag_remove = False)
                 if not flag_exists:
                     raise Exception("No se encontró coincidencias para: " + filename)
     
-def download_by_prefix_sftp(sftpPath, prefix, downloadPath, credentials, flag_remove = False):    
+def download_by_prefix_sftp(sftpPath="", prefix="", downloadPath="", credentials={}, flag_remove = False):
+    """Funcion que descarga archivos de un SFTP basado en prefijos
+
+    Args:
+        sftpPath (str, optional): Path origen del sftp. Defaults to "".
+        prefix (str, optional): Prefijo de archivo a descargar. Defaults to "".
+        downloadPath (str, optional): Path destino. Defaults to "".
+        credentials (dict, optional): Diccionario con credenciales. Defaults to {}.
+        flag_remove (bool, optional): Flag que permite borrar el archivo origen. Defaults to False.
+    """
+    
     import paramiko
 
     puerto = 22
@@ -369,12 +402,21 @@ def download_by_prefix_sftp(sftpPath, prefix, downloadPath, credentials, flag_re
     
     return
 
-def move_sftp(filenames, credentials):
-    """ Renombra un archivo en SFTP
-    :param filenames: Dictionario tipo 'Archivo original':'Archivo renombrado' (rutas absolutas)
-    :param credentials: Credenciales de conexion al SFTP
-    :return: None
+def move_sftp(filenames={}, credentials={}):
+    """Funcion que renombra un archivo en SFTP
+
+    Args:
+        filenames (dict, optional): Key archivo original y Value archivo destino. Defaults to {}.
+        credentials (dict, optional): Diccionario con credenciales del SFTP. Defaults to {}.
+
+    Raises:
+        Exception: Generado al fallar 
     """
+    #""" 
+    #:param filenames: Dictionario tipo 'Archivo original':'Archivo renombrado' (rutas absolutas)
+    #:param credentials: Credenciales de conexion al SFTP
+    #:return: None
+    #"""
     import paramiko
 
     puerto = 22
@@ -407,7 +449,17 @@ def get_info_pdf(file):
     p = doc.loadPage(0)       
     return p.getText()
 
-def send_mail_by_exe(credentials, mail):
+def send_mail_by_exe(credentials={}, mail={}):
+    """Funcion que permite ejecutar envio de correo a traves de un ejecutable inhouse.
+
+    Args:
+        credentials (dict, optional): Diccionario con credenciales del correo. Defaults to {}.
+        mail (dict, optional): Diccionario con datos del correo a enviar. Defaults to {}.
+
+    Raises:
+        Exception: Generado por no detectar los campos necesarios del envio
+        Exception: Generado al ejecutar el ejecutable mail.exe
+    """
     path = os.path.dirname(__file__)
     program = os.path.join(path,'mail.exe')
     
@@ -426,18 +478,24 @@ def send_mail_by_exe(credentials, mail):
         log.error("Ocurrio un error al ejecutar:" + program)
         raise Exception(e)
 
-def create_folders(lista_carpetas):
-    '''
-    Funcion que crea carpetas de trabajo
-    '''
+def create_folders(lista_carpetas=[]):
+    """Funcion que crea carpetas de trabajo
+
+    Args:
+        lista_carpetas (list, optional): Lista de carpetas a crear. Defaults to [].
+    """
+    
     for carpeta in lista_carpetas:
         if not os.path.exists(carpeta):
             os.makedirs(carpeta)
         
 def create_folder_env(dir_path):
-    '''
-    Funcion que crea las carpetas de trabajo estándar de trabajo
-    '''
+    """Funcion que crea las carpetas de trabajo estándar de trabajo
+
+    Args:
+        dir_path (str): Directorio raiz donde se desea crear la estructura
+    """
+
     dir_in = os.path.join(dir_path,"input")
     dir_out = os.path.join(dir_path,"output")
     dir_log = os.path.join(dir_path,"log")
@@ -454,35 +512,39 @@ def create_folder_env(dir_path):
     return
 
 def config_logging(file_log=None, level=logging.DEBUG, console=True):
-    '''
-    Funcion que configura la gestion de Logs
-    '''
+    """Funcion que configura la gestion de Logs
+
+    Args:
+        file_log (str, optional): Nombre del archivo log. Defaults to None.
+        level (logging.level, optional): Nivel de log. Defaults to logging.DEBUG.
+        console (bool, optional): Define si se acepta impresion en consola. Defaults to True.
+
+    Returns:
+        logger: logger de logging
+    """
     
     formatter = logging.Formatter('%(asctime)-5s %(filename)s %(lineno)d %(levelname)-8s %(message)s')
     
+    log=logging.getLogger(__name__)
+    
     #logging file
     if file_log and file_log != "":
         fh = logging.FileHandler(file_log)
         fh.setFormatter(formatter)
-        
+        log.addHandler(fh)
+    
+    #logging console
     if console:
         ch = logging.StreamHandler()
         ch.setFormatter(formatter)
-    
-    log=logging.getLogger(__name__)
-    
-    if file_log and file_log != "":
-        log.addHandler(fh)
-        log.info("Hangler: file")
-    
-    if console:
         log.addHandler(ch)
-        log.info("Hangler: console")
-    
+        
     log.setLevel(level=level)
-    
     log.info("Level log: " + logging.getLevelName(level))
     
+    for i in log.handlers:
+        log.info("Handler:" + type(i).__name__)
+    
     return log
 
 def check_if_string_in_file(filename, string_to_search):
@@ -497,16 +559,19 @@ def check_if_string_in_file(filename, string_to_search):
     return False
 
 class Configuration(object):
-    """
-    Clase que permite cargar dinámicamente los archivos de configuración del proceso.
-    """
+    """Clase que permite cargar dinámicamente los archivos de configuración del proceso."""
     
     def __init__(self, file_config="Config.ini", section_names=["DEFAULT"]):
-        r"""Inicializa los parametros de entrada
-        :param file_config: Ruta absoluta del archivo de configuración.
-        :param section_names: (optional) Lista de secciones a cargar.
-        :return: :class: object
+        """Inicializa los parametros de entrada
+
+        Args:
+            file_config (str, optional): Ruta absoluta del archivo de configuración. Defaults to "Config.ini".
+            section_names (list, optional): Lista de secciones a cargar. Defaults to ["DEFAULT"].
+
+        Raises:
+            ValueError: Generado al no encontrar el archivo de configuracion
         """
+        
         parser = configparser.ConfigParser(interpolation=EnvInterpolation())
         parser.optionxform = str
         found = parser.read(file_config)
@@ -527,12 +592,22 @@ class EnvInterpolation(configparser.BasicInterpolation):
         value = super().before_get(parser, section, option, value, defaults)
         return os.path.expandvars(value)
 
-def create_connection_sqlite(db_file):
+def create_connection_sqlite(db_file=""):
+    """ Funcion que crea una coneccion a la base de datos SQLite
+
+    Args:
+        db_file (str, optional): Ruta absoluta del archivo sqlite. Defaults to "".
+
+    Returns:
+        Connection: Coneccion sqlite
+    """
+    
     """ create a database connection to the SQLite database
         specified by db_file
     :param db_file: database file
     :return: Connection object or None
     """
+    
     conn = None
     try:
         conn = sqlite3.connect(db_file)
@@ -542,14 +617,16 @@ def create_connection_sqlite(db_file):
     return conn
 
 def get_now_format(format = "%Y%m%d%H%M%S%f"):
+    """Funcion que devuelve la fecha actual bajo un formato."""
     return str(datetime.now().strftime(format))
 
-def replace_string_in_file(filename_in, filename_out, dict_words):
-    """ Reemplaza cadenas de un archivo
-    :param filename_in: Archivo de entrada
-    :param filename_out: Archivo de salida
-    :param dict_words: Diccionario de palabras y valores a reemplazar
-    :return: None
+def replace_string_in_file(filename_in="", filename_out="", dict_words={}):
+    """Funcion que eemplaza cadenas de un archivo
+
+    Args:
+        filename_in (str, optional): Archivo entrada. Defaults to "".
+        filename_out (str, optional): Archivo salida. Defaults to "".
+        dict_words (dict, optional): Diccionario de palabras y valores a reemplazar. Defaults to {}.
     """
 
     write_obj = open(filename_out, 'w')
@@ -568,20 +645,27 @@ def replace_string_in_file(filename_in, filename_out, dict_words):
     write_obj.close()
 
 def sqlcmd(file_sql, credentials, file_sql_log, dict_variable = {}, validate_error = True, coding = "65001"):
-    """ Ejecuta el utilitario SQLCMD de SQLServer en linea de comandos
-    :param file_sql: Archivo sql a ejecutar
-    :param credentials: Credenciales de conexion a la Base de Datos SQLServer
-    :param file_sql_log: Archivo prefijo para generar archivo log (file_sql_log + ".ahora.db")
-    :param dict_variable: Diccionario de palabras y valores a reemplazar en el script sql
-    :param validate_error: Flag para generar exception si se encuentra la palabra error
-    :param coding: Formato de codificacion
-    :return: None
-    """
+    """Funcion que ejecuta el utilitario SQLCMD de SQLServer en linea de comandos
 
+    Args:
+        file_sql (str): Archivo SQL
+        credentials (dict): Diccionario con crediales SQL
+        file_sql_log (str): Archivo prefijo para generar archivo log (file_sql_log + ".ahora.db")
+        dict_variable (dict, optional): Diccionario de variables a reemplazar. Defaults to {}.
+        validate_error (bool, optional): Flag para generar exception si se encuentra la palabra error. Defaults to True.
+        coding (str, optional): Coding de respuesta. Defaults to "65001".
+
+    Raises:
+        FileNotFoundError: Se necesita ingresar archivo sql
+        Exception: Se necesita ingresar archivo log
+        Exception: Se encontro un error en el archivo log de la BD
+        Exception: Archivo output sqlcmd no generado
+    """
+    
+    sqlcmd_bin= '/opt/mssql-tools/bin/sqlcmd'
+    
     if os.name == 'nt':
         sqlcmd_bin = 'sqlcmd'
-    else:
-        sqlcmd_bin= '/opt/mssql-tools/bin/sqlcmd'
     
     if not os.path.exists(file_sql):
         raise FileNotFoundError(file_sql)
@@ -636,21 +720,27 @@ def sqlcmd(file_sql, credentials, file_sql_log, dict_variable = {}, validate_err
         raise Exception("Archivo output sqlcmd no generado.")
 
 def bcp(table, file, operation, credentials, file_sql_log, validate_error = True, coding = "-C 65001"):
-    """ Ejecuta el utilitario SQLCMD de SQLServer en linea de comandos
-    :param table: Tabla a trabajar
-    :param file: Archivo de entrada o salida segun la operacion
-    :param operation: operacion a ejecutar IN u OUT
-    :param credentials: Credenciales de conexion a la Base de Datos SQLServer
-    :param file_sql_log: Archivo prefijo para generar archivo log (file_sql_log + ".ahora.db")
-    :param validate_error: Flag para generar exception si se encuentra la palabra error
-    :param coding: Formato de codificacion
-    :return: None
+    """Funcion que ejecuta el utilitario BCP de SQLServer en linea de comandos
+
+    Args:
+        table (str): Tabla a trabajar
+        file (str): Archivo de entrada o salida segun la operacion
+        operation (str): operacion a ejecutar IN u OUT
+        credentials (str): Credenciales de conexion a la Base de Datos SQLServer
+        file_sql_log (str): Archivo prefijo para generar archivo log (file_sql_log + ".ahora.db")
+        validate_error (bool, optional): Flag para generar exception si se encuentra la palabra error. Defaults to True.
+        coding (str, optional): Coding de respuesta. Defaults to "65001".
+
+    Raises:
+        Exception: Se necesita ingresar archivo log
+        Exception: Operacion BCP no permitida
+        Exception: Se encontro un error en el archivo log de la BD
+        Exception: Archivo output bcp no generado
     """
     
+    bcpcmd_bin= '/opt/mssql-tools/bin/bcp'
     if os.name == 'nt':
         bcpcmd_bin = 'bcp'
-    else:
-        bcpcmd_bin= '/opt/mssql-tools/bin/bcp'
     
     if file_sql_log == "":
         raise Exception("Se necesita ingresar archivo log")
@@ -693,12 +783,17 @@ def bcp(table, file, operation, credentials, file_sql_log, validate_error = True
         raise Exception("Archivo output bcp no generado.")
 
 def get_data_from_sqllog(file_sql_log, file_result, prefix = "DATA:"):
-    """ Filtra las lineas de texto que comiencen con el prefijo
-    :param file_sql_log: Archivo de entrada a analizar
-    :param file_result: Archivo de salida con data filtrada
-    :param prefix: Prefijo a analizar
-    :return: None
+    """Funcion que filtra las lineas de texto que comiencen con el prefijo
+
+    Args:
+        file_sql_log (str): Archivo log de entrada
+        file_result (str): Archivo resultado
+        prefix (str, optional): Prefijo a filtrar los datos. Defaults to "DATA:".
+
+    Raises:
+        FileNotFoundError: Archivo de entrada no encontrado
     """
+    
     if not os.path.exists(file_sql_log):
         raise FileNotFoundError(file_sql_log)
     
@@ -717,17 +812,26 @@ def get_data_from_sqllog(file_sql_log, file_result, prefix = "DATA:"):
     file_out.close()
 
 def iter_all_strings():
-    """ Generator que devuelve lista de letras secuenciales
-    :return: yield
+    """Funcion que devuelve lista de letras secuenciales
+
+    Yields:
+        str: Secuencia
     """
+    
     for size in itertools.count(1):
         for s in itertools.product(ascii_lowercase, repeat=size):
             yield "".join(s)
 
 def enviar_correo_smtp(mail):
-    """ Funcion que envia correos via SMTP
-    :return: bool
+    """Funcion que envia correos via SMTP
+
+    Args:
+        mail (dict): Diccionanrio con credenciales smtp y cuerpo de correo
+
+    Returns:
+        bool: Resultado de ejecucion
     """
+    
     try:
         email_smtp_host  = mail['smtp_host']
         email_smtp_port  = mail['smtp_port']
@@ -778,9 +882,18 @@ def enviar_correo_smtp(mail):
     return True
 
 def comprimir(lista_objetos = [], nombre_salida = "archivo_salida", tipo_compresion = "tgz"):
-    """ Funcion que comprime archivos y carpetas
-    :return: None
+    """Funcion que comprime archivos y carpetas
+
+    Args:
+        lista_objetos (list, optional): Lista de objetos a comprimir. Defaults to [].
+        nombre_salida (str, optional): Nombre de archivo salida. Defaults to "archivo_salida".
+        tipo_compresion (str, optional): Tipo de compresion. Defaults to "tgz".
+
+    Raises:
+        Exception: Ocurrio un error en la compresion
+        Exception: Tipo compresion no identificada
     """
+    
     if tipo_compresion == "tgz":
         try:
             with tarfile.open( nombre_salida + ".tgz", "w:gz" ) as tar:
@@ -799,38 +912,24 @@ def convertir_local_a_utc(fecha_local):
     return fecha_utc
 
 class RpaNotificacionCorreo:
-    """
-    Clase que define la configuracion y metodos para el envio de Correo.
-    """
+    """Clase que define la configuracion y metodos para el envio de Correo."""
+    
     def __init__(self, host="10.226.5.191", port="25", secure_mode=None, use_executable=False, **kwargs):
-        """
-        Funcion que carga los valores plantilla del correo a enviar.
-        
-        Parameters
-        ----------
-        host : str
-            Ip del servidor de correos SMTP.
-        port : str
-            Puerto del servidor de correos SMTP.
-        secure_mode : str. Opcional
-            Modo seguro para autenticarse. Solo puede ingresarse SSL o TLS.
-        use_executable : bool. Opcional
-            Booleano que determina si se debe o no usar el .exe (contigencia).
-            
-        **kwargs : optional
-            Parametros opcionales para la autenticacion
-            user
-            password
+        """Funcion que inicializa valores plantilla del correo a enviar
 
-        Returns
-        -------
-        None
-            
-        Raises
-        ------
-        ValueError
-            Si existe alguna inconsistencia en los parametros de entrada
+        Args:
+            host (str, optional): Ip del servidor de correos SMTP. Defaults to "10.226.5.191".
+            port (str, optional): Puerto del servidor de correos SMTP. Defaults to "25".
+            secure_mode (_type_, optional): Modo seguro para autenticarse. Solo puede ingresarse SSL o TLS. Defaults to None.
+            use_executable (bool, optional): Booleano que determina si se debe o no usar el .exe (contigencia). Defaults to False.
+            **kwargs : optional
+                Parametros opcionales para la autenticacion
+                user
+                password
+        Raises:
+            ValueError: secure_mode: Solo pude ingresar el modo seguro SSL o TLS
         """
+        
         self.host = host
         self.port = port
         
@@ -860,14 +959,12 @@ class RpaNotificacionCorreo:
         self.email_cco  = []
 
     def __str__(self):
+        """Funcion que devuelve los parametros configurados en los atributos.
+
+        Returns:
+            str: Servidor + Plantilla
         """
-        Funcion que devuelve los parametros configurados en los atributos.
-        
-        Returns
-        -------
-        String
-            Servidor + Plantilla
-        """
+       
         con = ''
         if not self.use_auth:
             con += "Servidor : " + self.host + ":" + self.port + "\n"
@@ -884,36 +981,26 @@ class RpaNotificacionCorreo:
         return con        
     
     def cargar_plantilla(self, subject_template=None, body_template=None, email_from=None, email_to=None, email_cc=None, email_cco=None):
-        """
-        Funcion que carga los valores plantilla del correo a enviar.
-        
-        Parameters
-        ----------
-        subject_template : str. Opcional
-            Asunto plantilla a usar en el correo.
-        body_template : str. Opcional
-            Cuerpo plantilla a usar en el correo.
-        email_from : str
-            Emisor a colocar en el correo a enviar. 
-        email_to : str. Opcional
-            Destinatarios a colocar en el correo a enviar. Si existe mas de uno,
-            colocar como separador ';'
-        email_cc : str. Opcional
-            Destinatarios Con Copia a colocar en el correo a enviar. Si existe mas de uno,
-            colocar como separador ';'
-        email_cco : str. Opcional
-            Destinatarios Con Copia Oculta a colocar en el correo a enviar. Si existe mas de uno,
-            colocar como separador ';'
-        
-        Returns
-        -------
-        None
-            
-        Raises
-        ------
-        ValueError
-            Si existe alguna inconsistencia en los parametros de entrada
-        """
+        """Funcion que carga los valores plantilla del correo a enviar.
+
+        Args:
+            subject_template (_type_, optional): Asunto plantilla a usar en el correo. Defaults to None.
+            body_template (_type_, optional): Cuerpo plantilla a usar en el correo. Defaults to None.
+            email_from (_type_, optional): Emisor a colocar en el correo a enviar. Defaults to None.
+            email_to (_type_, optional): Destinatarios a colocar en el correo a enviar. Si existe mas de uno,
+                                         colocar como separador ';'. Defaults to None.
+            email_cc (_type_, optional): Destinatarios Con Copia a colocar en el correo a enviar. Si existe mas de uno,
+                                         colocar como separador ';'. Defaults to None.
+            email_cco (_type_, optional): Destinatarios Con Copia Oculta a colocar en el correo a enviar. Si existe mas de uno,
+                                          colocar como separador ';'. Defaults to None.
+
+        Raises:
+            ValueError: From: Debe ingresar un correo
+            ValueError: From: Debe ingresar una cadena de correo(s) separados por ';'
+            ValueError: Cc: Solo puede ingresar una cadena de correos separado por ';'
+            ValueError: Cco: Solo puede ingresar una cadena de correos separado por ';'
+            ValueError: Debe ingresar al menos un correo destinatario
+        """        
         
         if subject_template:
             self.subject = subject_template
@@ -942,31 +1029,25 @@ class RpaNotificacionCorreo:
         self.email_cco  = email_cco.split(";") if type(email_cco) == str else []
         
     def enviar_correo(self, subject_replace=None, body_replace=None, attachment_files=None):
-        """
-        Funcion que envia correos.
-        
-        Parameters
-        ----------
-        subject_replace : dict. Opcional
-            Palabras clave a reemplazar en el asunto del correo. Cada llave del diccionario 
-            será buscada en la plantilla cargada inicialmente y reemplazada por su valor.
-        body_replace : dict. Opcional
-            Palabras clave a reemplazar en el cuerpo del correo. Cada llave del diccionario 
-            será buscada en la plantilla cargada inicialmente y reemplazada por su valor.
-        attachment_files : str. Opcional
-            Cadena de archivos a adjuntar en el correo. Los archivos deben tener la ruta
-            absoluta y estar separados por ';' en caso de existir mas de uno.
-        
-        Returns
-        -------
-        Boolean
-            Se devolvera True si es que no se genero alguna excepcion. De lo contrario el valor
-            devuelto sera False.
-        
-        Raises
-        ------
-        Exception
-            Si existe una excepcion en el flujo, solo se captura e imprime el exc_info.
+        """Funcion que envia correos
+
+        Args:
+            subject_replace (_type_, optional): Palabras clave a reemplazar en el asunto del correo.
+                                                Cada llave del diccionario será buscada en la plantilla 
+                                                cargada inicialmente y reemplazada por su valor. Defaults to None.
+            body_replace (_type_, optional): Palabras clave a reemplazar en el cuerpo del correo.
+                                             Cada llave del diccionario será buscada en la plantilla cargada
+                                             inicialmente y reemplazada por su valor.. Defaults to None.
+            attachment_files (_type_, optional): Cadena de archivos a adjuntar en el correo. Los archivos
+                                                 deben tener la ruta absoluta y estar separados por ';' en caso
+                                                 de existir mas de uno. Defaults to None.
+
+        Raises:
+            ValueError: Ocurrio un error al enviar el correo
+
+        Returns:
+            bool: Se devolvera True si es que no se genero alguna excepcion. De lo contrario el valor
+                  devuelto sera False
         """
         
         try:
@@ -1070,13 +1151,12 @@ class RpaNotificacionCorreo:
             
         return True
 
-#Función del bisiesto en el util.rpa
 def isleap(year):
-    """Return True for leap years, False for non-leap years."""
+    """Funcion que devuelve True para años bisiestos y False para los que no lo son"""
     return year % 4 == 0 and (year % 100 != 0 or year % 400 == 0)
 
 def feriados_santos(anio):
-    """Función de feriados santos"""
+    """Función que devuelve feriados santos"""
     #Calcular el resto de la division año/19
     a = anio%19
     #Calcular el cociente entero de la division año/100
